@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
- *  Copyright (C) 2004 Crispin Flowerday
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
+ *  Copyright © 2004 Crispin Flowerday
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.1 2004/09/27 16:58:20 chpe Exp $
+ *  $Id: extension.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-sidebar-extension.h"
 #include "ephy-sidebar-embed.h"
@@ -37,7 +35,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphySidebarExtension")
+	LOG ("Registering EphySidebarExtension");
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
